#

##

##

###

###

###

###

###

###

###

    		from .py

    		tutorial

    import pathlib
    from os.path import dirname, join, normpath
    import Emergency

    import time
    import rich

    this_directory = pathlib.Path (__file__).parent.resolve ()
    this_module = str (this_directory)
    the_guarantees = str (normpath (join (this_directory, f"guarantees")))

    relative_path = str (normpath (join (this_directory, f"..")))

    bio = Emergency.on ({
    	"glob_string": this_module + "/**/guarantee_*.py",

    	"simultaneous": True,
    	"simultaneous_capacity": 10,

    	"time_limit": 60,

    	"module_paths": [
    		normpath (join (this_module, "modules"))
    	],

    	"relative_path": relative_path,

    	"aggregation_format": 2
    })

    bio ["off"] ()
    scan = bio ["proceeds"]

    rich.print_json (data = proceeds)

    		summary

    			glob_string
    			Anything found in the glob string is treated as a status check file.

    			simultaneous
    			A boolean that says if the checks should be run at the same time.

    			simultaneous_capacity
    			A limiter on the amount of checks that can be run at once.

    			time_limit
    			After the time_limit expires, checks fail.
    			This can prevent an infinite loop from barricading the presentation of results.

    			module_paths
    			These are added to the sys.path of every check.

    			relative_path
    			This path is removed from the path of each status check path in the "proceeds".

    			aggregation_format
    			This should be 2.  1 is outdated.